# CHANGELOG


## v0.2.1 (2025-05-21)

### Bug Fixes

- Provide a similar interface as scipys least_square
  ([`7084535`](https://github.com/arunoruto/lumafit/commit/708453507b270cc536c2b92b706c0d86552c8b4f))


## v0.2.0 (2025-05-21)

### Bug Fixes

- Typing for n_iter_results
  ([`633ce99`](https://github.com/arunoruto/lumafit/commit/633ce99983f06d418f64a153ec8717f95f884ddf))

### Continuous Integration

- Only run one flake check
  ([`2954b5e`](https://github.com/arunoruto/lumafit/commit/2954b5ed3158bb85d4ab2e617a0182230697fe49))

### Documentation

- Add docs packages and enable them in flake.nix
  ([`4edbec0`](https://github.com/arunoruto/lumafit/commit/4edbec08f0c1c4154c5a6419d0493f72246a514e))

- Add sphinx documentation and autobuild
  ([`e6f71ae`](https://github.com/arunoruto/lumafit/commit/e6f71aea5d58944bd5fc30111823b0ed4b8797a2))

### Features

- Add option for custom jacobian
  ([`addbad5`](https://github.com/arunoruto/lumafit/commit/addbad55d445fb48b5c205662be70c737e7a5677))


## v0.1.0 (2025-05-20)

### Features

- Init commit
  ([`3d27720`](https://github.com/arunoruto/lumafit/commit/3d27720e5d6f08005e25109db7918cbf59944fd8))
